@@ -1,11 +1,10 @@
-// $Id: options.cc,v 1.29 2001/06/17 18:15:15 cactus Exp $
+// $Id: options.cc,v 1.32 2001/11/23 23:07:29 cactus Exp $
 /*
   Gnomoku Copyright (C) 1998-1999 NAGY Andrs <nagya@telnet.hu>
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 2
-  (included in the RadioActive distribution in doc/GPL) as published by
-  the Free Software Foundation.
+  as published by the Free Software Foundation.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,15 +16,21 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
-#include "config.h"
-
 #include "options.h"
+
+#include "config.h"
+#include <libgnome/libgnome.h>
+
 #include <vector>
 
-using namespace Gtk;
-using namespace Gnome;
+#include <gtk--/menu.h>
+#include <gtk--/table.h>
+#include <gtk--/box.h>
+#include <gnome--/stock.h>
+
+using namespace Gnomoku;
+using std::string;
 
-// OPTIONS
 Options::Options(op_t &optype_,
 		 string &host_, string &port_,
 		 bool &beep_):
@@ -34,7 +39,7 @@ Options::Options(op_t &optype_,
     host_label (_("Host name:"),   0, 0.5),
     port_label (_("Port number:"), 0, 0.5),
 
-    beep_check (_("Beep on your turn")),
+    beep_check (_("Beep on my turn")),
     
     optype(optype_),
     host (host_),
@@ -53,49 +58,50 @@ Options::Options(op_t &optype_,
     port_entry.set_max_length(5);
 
     // Dropdown list
-    Menu* menu = manage(new Menu);
-    MenuItem* item;
-    item = manage(new MenuItem(_("Computer AI")));
-    item->activate.connect(bind(slot(this, &Options::op_change),
-				OP_AI));
-    menu->append(*item);
+    Gtk::Menu     *menu = new Gtk::Menu;
+    Gtk::MenuItem *item;
+    item = new Gtk::MenuItem (_("Computer AI"));
+    item->activate.connect (SigC::bind (SigC::slot (this, &Options::op_change), OP_AI));
+    menu->append (*manage (item));
     
-    item = manage(new MenuItem(_("Net, I'm the client")));
-    item->activate.connect(bind(slot(this, &Options::op_change),
-				OP_CLIENT));
-    menu->append(*item);
+    item = new Gtk::MenuItem(_("Net, I'm the client"));
+    item->activate.connect (SigC::bind (SigC::slot (this, &Options::op_change), OP_CLIENT));
+    menu->append (*manage (item));
     
-    item = manage(new MenuItem(_("Net, I'm the server")));
-    item->activate.connect(bind(slot(this, &Options::op_change),
-				OP_SERVER));
-    menu->append(*item);
+    item = new Gtk::MenuItem(_("Net, I'm the server"));
+    item->activate.connect (SigC::bind (SigC::slot (this, &Options::op_change), OP_SERVER));
+    menu->append (*manage (item));
 
     menu->show_all();
-    op_combo.set_menu(*menu);
+    op_combo.set_menu(*manage (menu));
     
-    Table* table = new Table(4, 3, false);
-    table->set_row_spacings(10);
-    table->set_col_spacings(10);
+    // Beep check button
+    Gtk::Label *label = static_cast<Gtk::Label*> (beep_check.get_child ());
+    label->set_alignment (0, 0.5);
+    
+    Gtk::Table* table = new Gtk::Table (4, 3, false);
+    table->set_row_spacings (10);
+    table->set_col_spacings (10);
 
-    table->attach(op_label, 0, 1, 0, 1);
-    table->attach(op_combo, 1, 2, 0, 1);
+    table->attach (op_label, 0, 1, 0, 1);
+    table->attach (op_combo, 1, 2, 0, 1);
 
-    table->attach(host_label, 0, 1, 1, 2);
-    table->attach(host_entry, 1, 2, 1, 2);
-    table->attach(port_label, 0, 1, 2, 3);
-    table->attach(port_entry, 1, 2, 2, 3);
+    table->attach (host_label, 0, 1, 1, 2);
+    table->attach (host_entry, 1, 2, 1, 2);
+    table->attach (port_label, 0, 1, 2, 3);
+    table->attach (port_entry, 1, 2, 2, 3);
 
-    table->attach(beep_check, 1, 2, 3, 4);
+    table->attach (beep_check, 0, 2, 3, 4);
 
     // Buttons
     append_button (_("OK"),     GNOME_STOCK_BUTTON_OK);
     append_button (_("Cancel"), GNOME_STOCK_BUTTON_CANCEL);
-    set_default(0);
-    set_close(true);
-    clicked.connect(slot(this, &Options::button_clicked));    
+    set_default (0);
+    set_close (true);
+    clicked.connect (SigC::slot (this, &Options::button_clicked));    
 
-    get_vbox()->add(*table);
-    show_all();
+    table->show_all ();
+    get_vbox ()->add (*table);
 }
 
 void Options::update()
@@ -113,9 +119,9 @@ void Options::update()
 	break;
     }
     
-    host_entry.set_text(host);
-    port_entry.set_text(port);
-    beep_check.set_active(beep);
+    host_entry.set_text (host);
+    port_entry.set_text (port);
+    beep_check.set_active (beep);
     apply_op (optype);
 }
 
@@ -165,7 +171,7 @@ void Options::op_change (op_t op)
     optype_cache = op;
 }
 
-gint Options::delete_event_impl (GdkEventAny *)
+int Options::delete_event_impl (GdkEventAny *)
 {
     hide();
     return false;
