@@ -1,11 +1,10 @@
-// $Id: point.cc,v 1.18 2000/02/01 21:25:54 cactus Exp $
+// $Id: point.cc,v 1.21 2001/11/23 23:07:29 cactus Exp $
 /*
   Gnomoku Copyright (C) 1998-1999 NAGY Andrs <nagya@telnet.hu>
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 2
-  (included in the RadioActive distribution in doc/GPL) as published by
-  the Free Software Foundation.
+  as published by the Free Software Foundation.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,24 +16,26 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
+#include "config.h"
+
 #include "point.h"
 
 #include "px0.xpm"
 #include "px1.xpm"
 #include "px2.xpm"
 
-using namespace Gtk;
-using namespace SigC;
+#include <gtk--/main.h>
 
 char **pixdata[3] = { px0_xpm, px1_xpm, px2_xpm };
 
-// POINT
+using namespace Gnomoku;
+
 bool Point::initialized = false;
 SigC::Signal0<void> Point::blink_sig;
 
 void Point::init()
 {
-    Main::timeout.connect(slot(&blink_method), 500);
+    Gtk::Main::timeout.connect (SigC::slot (&blink_method), 500);
     initialized = true;
 }
 
@@ -74,9 +75,9 @@ void Point::set_blink(bool b)
 
 void Point::vset(int vp_)
 {
-    if (!initialized) init();
+    if (!initialized)
+	init();
     vp = vp_;
-//    px.set(pixmaps[vp], bitmaps[vp]);
     px.load(pixdata[vp]);
 }
     
